task AlignToSenseOnly {
    
    String sample_id
    File in_fastq

    String refname
    
    File dir_index
    String prefix_index 

    Int max_mismatch_allowed
    
    String docker
    String cluster_config
    String disk_size

    command <<<
        set -o pipefail
        set -e
        nt=$(nproc)

        bowtie --threads $nt \
            ${dir_index}/${prefix_index} --norc \
            -v ${max_mismatch_allowed} \
            -q ${in_fastq} \
            --un ${sample_id}.${refname}Unaligned.fastq \
            -S ${sample_id}.align2${refname}.sam \
        2> ${sample_id}.align2${refname}.log

        gzip ${sample_id}.${refname}Unaligned.fastq
    >>>

    runtime {
        docker: docker
        cluster: cluster_config
        systemDisk: "cloud_ssd 40" 
        dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
    }

    output {
        File out_sam="${sample_id}.align2${refname}.sam"
        File out_fastq="${sample_id}.${refname}Unaligned.fastq.gz"
        File out_log="${sample_id}.align2${refname}.log"
    }
}

task AlignToBothStrand {
    
    String sample_id
    File in_fastq

    String refname
    
    File dir_index
    String prefix_index 

    Int max_mismatch_allowed
    
    String docker
    String cluster_config
    String disk_size

    command <<<
        set -o pipefail
        set -e
        nt=$(nproc)

        bowtie --threads $nt \
            ${dir_index}/${prefix_index} \
            -v ${max_mismatch_allowed} \
            -q ${in_fastq} \
            --un ${sample_id}.${refname}Unaligned.fastq \
            -S ${sample_id}.align2${refname}.sam \
        2> ${sample_id}.align2${refname}.log

        gzip ${sample_id}.${refname}Unaligned.fastq
    >>>

    runtime {
        docker: docker
        cluster: cluster_config
        systemDisk: "cloud_ssd 40" 
        dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
    }

    output {
        File out_sam="${sample_id}.align2${refname}.sam"
        File out_fastq="${sample_id}.${refname}Unaligned.fastq.gz"
        File out_log="${sample_id}.align2${refname}.log"
    }
}